@@ -102,9 +102,11 @@ enum LOG_STREAM
   LOG_NLS_JAC,
   LOG_NLS_JAC_TEST,
   LOG_NLS_RES,
+  LOG_NLS_EXTRAPOLATE,
   LOG_RES_INIT,
   LOG_SIMULATION,
   LOG_SOLVER,
+  LOG_SOLVER_CONTEXT,
   LOG_SOTI,
   LOG_STATS,
   LOG_STATS_V,
