@@ -45,22 +45,25 @@ enum _FLAG
   FLAG_ALARM,
   FLAG_CLOCK,
   FLAG_CPU,
+  FLAG_CSV_OSTEP,
   FLAG_DASSL_JACOBIAN,
-  FLAG_DASSL_NO_ROOTFINDING,
   FLAG_DASSL_NO_RESTART,
+  FLAG_DASSL_NO_ROOTFINDING,
   FLAG_EMIT_PROTECTED,
   FLAG_F,
   FLAG_HELP,
+  FLAG_IGNORE_HIDERESULT,
   FLAG_IIF,
   FLAG_IIM,
   FLAG_IIT,
   FLAG_ILS,
   FLAG_INITIAL_STEP_SIZE,
+  FLAG_INPUT_CSV,
   FLAG_INPUT_FILE,
   FLAG_INPUT_FILE_STATES,
   FLAG_IPOPT_HESSE,
-  FLAG_IPOPT_JAC,
   FLAG_IPOPT_INIT,
+  FLAG_IPOPT_JAC,
   FLAG_IPOPT_MAX_ITER,
   FLAG_IPOPT_WARM_START,
   FLAG_L,
@@ -68,8 +71,8 @@ enum _FLAG
   FLAG_LS,
   FLAG_LS_IPOPT,
   FLAG_LV,
-  FLAG_MAX_STEP_SIZE,
   FLAG_MAX_ORDER,
+  FLAG_MAX_STEP_SIZE,
   FLAG_MEASURETIMEPLOTFORMAT,
   FLAG_NEWTON_STRATEGY,
   FLAG_NLS,
@@ -80,15 +83,15 @@ enum _FLAG
   FLAG_NOEQUIDISTANT_OUT_TIME,
   FLAG_NOEVENTEMIT,
   FLAG_OPTDEBUGEJAC,
+  FLAG_OPTIMIZER_NP,
+  FLAG_OPTIMIZER_TGRID,
   FLAG_OUTPUT,
   FLAG_OVERRIDE,
   FLAG_OVERRIDE_FILE,
-  FLAG_OPTIMIZER_NP,
-  FLAG_OPTIMIZER_TGRID,
-  FLAG_UP_HESSIAN,
   FLAG_PORT,
   FLAG_R,
   FLAG_S,
+  FLAG_UP_HESSIAN,
   FLAG_W,
 
   FLAG_MAX
@@ -125,6 +128,7 @@ enum SOLVER_METHOD
   S_LOBATTO6,      /* 10 */
   S_SYM_EULER,     /* 11 */
   S_SYM_IMP_EULER, /* 12 */
+  S_HEUN,          /* 13 */
   S_QSS,
 
   S_MAX
@@ -152,6 +156,7 @@ enum LINEAR_SOLVER
 #if !defined(OMC_MINIMAL_RUNTIME)
   LS_LIS,
 #endif
+  LS_KLU,
   LS_UMFPACK,
   LS_TOTALPIVOT,
   LS_DEFAULT,
