@@ -21,15 +21,15 @@ public:
     {
     }
 
-    virtual boost::shared_ptr<ILinSolverSettings> createLinSolverSettings(string lin_solver)
+    virtual shared_ptr<ILinSolverSettings> createLinSolverSettings(string lin_solver)
     {
-        boost::shared_ptr<ILinSolverSettings> linsolversetting;
+        shared_ptr<ILinSolverSettings> linsolversetting;
         return linsolversetting;
     }
 
-    virtual boost::shared_ptr<IAlgLoopSolver> createLinSolver(IAlgLoop* algLoop, string solver_name, boost::shared_ptr<ILinSolverSettings> solver_settings)
+    virtual shared_ptr<IAlgLoopSolver> createLinSolver(IAlgLoop* algLoop, string solver_name, shared_ptr<ILinSolverSettings> solver_settings)
     {
-        boost::shared_ptr<IAlgLoopSolver> solver;
+        shared_ptr<IAlgLoopSolver> solver;
         return solver;
     }
 
