@@ -5,6 +5,18 @@
 #include <Core/ModelicaDefine.h>
 #include <Core/Modelica.h>
 #if defined(__vxworks)
+#include <Solver/Newton/Newton.h>
+#include <Solver/Newton/NewtonSettings.h>
+
+extern "C" IAlgLoopSolver* createNewton(IAlgLoop* algLoop, INonLinSolverSettings* settings)
+{
+    return new Newton(algLoop, settings);
+}
+
+extern "C" INonLinSolverSettings* createNewtonSettings()
+{
+    return new NewtonSettings();
+}
 
 
 #elif defined(OMC_BUILD) && !defined(RUNTIME_STATIC_LINKING)
@@ -24,14 +36,14 @@ BOOST_EXTENSION_TYPE_MAP_FUNCTION {
 #elif defined(OMC_BUILD) && defined(RUNTIME_STATIC_LINKING)
 #include <Solver/Newton/Newton.h>
 #include <Solver/Newton/NewtonSettings.h>
- boost::shared_ptr<INonLinSolverSettings> createNewtonSettings()
+ shared_ptr<INonLinSolverSettings> createNewtonSettings()
  {
-     boost::shared_ptr<INonLinSolverSettings> settings = boost::shared_ptr<INonLinSolverSettings>(new NewtonSettings());
+     shared_ptr<INonLinSolverSettings> settings = shared_ptr<INonLinSolverSettings>(new NewtonSettings());
       return settings;
  }
- boost::shared_ptr<IAlgLoopSolver> createNewtonSolver(IAlgLoop* algLoop, boost::shared_ptr<INonLinSolverSettings> solver_settings)
+ shared_ptr<IAlgLoopSolver> createNewtonSolver(IAlgLoop* algLoop, shared_ptr<INonLinSolverSettings> solver_settings)
  {
-     boost::shared_ptr<IAlgLoopSolver> solver = boost::shared_ptr<IAlgLoopSolver>(new Newton(algLoop,solver_settings.get()));
+     shared_ptr<IAlgLoopSolver> solver = shared_ptr<IAlgLoopSolver>(new Newton(algLoop,solver_settings.get()));
         return solver;
  }
 #else
