@@ -32,7 +32,6 @@
  *
  * @author Adeel Asghar <adeel.asghar@liu.se>
  *
- * RCS: $Id$
  *
  */
 
@@ -53,7 +52,7 @@ QString Helper::omFileTypes = "Modelica Files (*.mo)";
 QString Helper::omnotebookFileTypes = "OMNotebook Files (*.onb *.onbz *.nb)";
 QString Helper::ngspiceNetlistFileTypes = "ngspice Netlist Files (*.cir *.sp *.spice)";
 QString Helper::imageFileTypes = "SVG (*.svg);;PNG image (*.png);;Windows BMP image (*.bmp);;TIFF (*.tiff)";
-QString Helper::bitmapFileTypes = "PNG image (*.png);;Windows BMP image (*.bmp);;JPEG (*.jpg *.jpeg)";
+QString Helper::bitmapFileTypes = "PNG image (*.png);Windows BMP image (*.bmp);JPEG (*.jpg *.jpeg)";
 QString Helper::fmuFileTypes = "FMU Files (*.fmu)";
 QString Helper::xmlFileTypes = "XML Files (*.xml)";
 QString Helper::infoXmlFileTypes = "OM Info Files (*_info.xml *_info.json)";
@@ -92,13 +91,8 @@ QString Helper::textOutput = "Text";
 QString Helper::utf8 = "UTF-8";
 QFontInfo Helper::systemFontInfo = QFontInfo(QFont());
 QFontInfo Helper::monospacedFontInfo = QFontInfo(QFont());
-QString Helper::defaultComponentAnnotationString = QString("{-100.0,-100.0,100.0,100.0,true,0.1,2.0,2.0,"
-                                                  "{Rectangle(true, {0.0, 0.0}, 0, {0, 0, 0}, {240, 240, 240}, LinePattern.Solid, FillPattern.Solid, 0.25, BorderPattern.None, {{-100, 100}, {100, -100}}, 0),"
-                                                  "Text(true, {0.0, 0.0}, 0, {0, 0, 0}, {0, 0, 0}, LinePattern.Solid, FillPattern.None, 0.25, {{-100, 20}, {100, -20}}, \"%name\", 0, TextAlignment.Center)}}");
-QString Helper::errorComponentAnnotationString = QString("{-100.0,-100.0,100.0,100.0,false,0.1,2.0,2.0,"
-                                                         "{Rectangle(true, {0.0, 0.0}, 0, {255, 0, 0}, {0, 0, 0}, LinePattern.Solid, FillPattern.None, 0.25, BorderPattern.None, {{-100, -100}, {100, 100}}, 0),"
-                                                         "Line(true, {0.0, 0.0}, 0, {{-100, 100}, {100, -100}}, {255, 0, 0}, LinePattern.Solid, 0.25, {Arrow.None, Arrow.None}, 3, Smooth.None),"
-                                                         "Line(true, {0.0, 0.0}, 0, {{100, 100}, {-100, -100}}, {255, 0, 0}, LinePattern.Solid, 0.25, {Arrow.None, Arrow.None}, 3, Smooth.None)}}");
+QString Helper::toolsOptionsPath = "Tools->Options";
+QString Helper::toolsOptionsPathMAC = "OMEdit->Preferences";
 /* Meta Modelica Types */
 QString Helper::MODELICA_METATYPE = QString("modelica_metatype");
 QString Helper::MODELICA_STRING = QString("modelica_string");
@@ -120,7 +114,6 @@ QString Helper::REAL = QString("Real");
 /* Global translated variables */
 QString Helper::newModelicaClass;
 QString Helper::createNewModelicaClass;
-QString Helper::findClasses;
 QString Helper::openModelicaFiles;
 QString Helper::openConvertModelicaFiles;
 QString Helper::libraries;
@@ -139,6 +132,11 @@ QString Helper::properties;
 QString Helper::add;
 QString Helper::edit;
 QString Helper::save;
+QString Helper::saveTip;
+QString Helper::saveAs;
+QString Helper::saveAsTip;
+QString Helper::saveTotal;
+QString Helper::saveTotalTip;
 QString Helper::apply;
 QString Helper::chooseDirectory;
 QString Helper::general;
@@ -184,7 +182,7 @@ QString Helper::unloadClass;
 QString Helper::duplicate;
 QString Helper::duplicateTip;
 QString Helper::unloadClassTip;
-QString Helper::unloadXMLTip;
+QString Helper::unloadTLMOrTextTip;
 QString Helper::refresh;
 QString Helper::simulate;
 QString Helper::simulateTip;
@@ -248,15 +246,15 @@ QString Helper::iconView;
 QString Helper::diagramView;
 QString Helper::textView;
 QString Helper::documentationView;
-QString Helper::searchModelicaClass;
+QString Helper::searchClasses;
 QString Helper::findReplaceModelicaText;
 QString Helper::left;
 QString Helper::center;
 QString Helper::right;
-QString Helper::connectArray;
+QString Helper::createConnection;
 QString Helper::findVariables;
-QString Helper::viewClass;
-QString Helper::viewClassTip;
+QString Helper::openClass;
+QString Helper::openClassTip;
 QString Helper::viewDocumentation;
 QString Helper::viewDocumentationTip;
 QString Helper::dontShowThisMessageAgain;
@@ -299,13 +297,16 @@ QString Helper::tlmCoSimulationSetupTip;
 QString Helper::tlmCoSimulation;
 QString Helper::running;
 QString Helper::finished;
+QString Helper::newVariable;
+QString Helper::library;
+QString Helper::moveUp;
+QString Helper::moveDown;
 
 void Helper::initHelperVariables()
 {
   /* Global translated variables */
   Helper::newModelicaClass = tr("New Modelica Class");
   Helper::createNewModelicaClass = tr("Create New Modelica Class");
-  Helper::findClasses = tr("Find Classes");
   Helper::openModelicaFiles = tr("Open Model/Library File(s)");
   Helper::openConvertModelicaFiles = tr("Open/Convert Modelica File(s) With Encoding");
   Helper::libraries = tr("Libraries");
@@ -324,6 +325,11 @@ void Helper::initHelperVariables()
   Helper::add = tr("Add");
   Helper::edit = tr("Edit");
   Helper::save = tr("Save");
+  Helper::saveTip = tr("Save a file");
+  Helper::saveAs = tr("Save As");
+  Helper::saveAsTip = tr("Save a copy of the class in a new file");
+  Helper::saveTotal = tr("Save Total");
+  Helper::saveTotalTip = tr("Save class with all used classes");
   Helper::apply = tr("Apply");
   Helper::importFMU = tr("Import FMU");
   Helper::chooseDirectory = tr("Choose Directory");
@@ -370,7 +376,7 @@ void Helper::initHelperVariables()
   Helper::duplicateTip = tr("Duplicates the item");
   Helper::unloadClass = tr("Unload");
   Helper::unloadClassTip = tr("Unload the Modelica class");
-  Helper::unloadXMLTip = tr("Unload the XML file");
+  Helper::unloadTLMOrTextTip = tr("Unload the TLM/Text file");
   Helper::refresh = tr("Refresh");
   Helper::simulate = tr("Simulate");
   Helper::simulateTip = tr("Simulates the Modelica class");
@@ -434,15 +440,15 @@ void Helper::initHelperVariables()
   Helper::diagramView = tr("Diagram View");
   Helper::textView = tr("Text View");
   Helper::documentationView = tr("Documentation View");
-  Helper::searchModelicaClass = tr("Search Modelica Class");
+  Helper::searchClasses = tr("Search Classes");
   Helper::findReplaceModelicaText = tr("Find/Replace...");
   Helper::left = tr("Left");
   Helper::center = tr("Center");
   Helper::right = tr("Right");
-  Helper::connectArray = tr("Connect Array");
+  Helper::createConnection = tr("Create Connection");
   Helper::findVariables = tr("Find Variables");
-  Helper::viewClass = tr("View Class");
-  Helper::viewClassTip = tr("Opens the class details");
+  Helper::openClass = tr("Open Class");
+  Helper::openClassTip = tr("Opens the class details");
   Helper::viewDocumentation = tr("View Documentation");
   Helper::viewDocumentationTip = tr("Opens the class documentation");
   Helper::dontShowThisMessageAgain = tr("Don't show this message again");
@@ -474,7 +480,7 @@ void Helper::initHelperVariables()
   Helper::parsingFailedJson = tr("Parsing of JSON file failed");
   Helper::expandAll = tr("Expand All");
   Helper::collapseAll = tr("Collapse All");
-  Helper::version = tr("Version:");
+  Helper::version = tr("Version");
   Helper::unlimited = tr("unlimited");
   Helper::simulationOutput = tr("Simulation Output");
   Helper::cancelSimulation = tr("Cancel Simulation");
@@ -485,6 +491,10 @@ void Helper::initHelperVariables()
   Helper::tlmCoSimulation = tr("TLM Co-Simulation");
   Helper::running = tr("Running");
   Helper::finished = tr("Finished");
+  Helper::newVariable = tr("<New Variable>");
+  Helper::library = tr("Library");
+  Helper::moveUp = tr("Move Up");
+  Helper::moveDown = tr("Move Down");
 }
 
 QString GUIMessages::getMessage(int type)
@@ -517,10 +527,10 @@ QString GUIMessages::getMessage(int type)
       return tr("Could not find environment variable OPENMODELICAHOME. Please make sure OpenModelica is installed properly.");
     case ERROR_OCCURRED:
       return tr("Following error has occurred. \n\n%1");
-    case ERROR_IN_MODELICA_TEXT:
-      return tr("Problems are found in Modelica Text. <br />");
+    case ERROR_IN_TEXT:
+      return tr("Problems are found in %1 Text. <br />");
     case REVERT_PREVIOUS_OR_FIX_ERRORS_MANUALLY:
-      return tr("<br /><br />For normal users it is recommended to choose <b>Revert from previous</b>. You can also choose <b>Fix errors manually</b> if you want to fix them by your own.");
+      return tr("<br /><br />If you cannot find the source of the error, you can always <b>revert to the last correct version</b>.");
     case NO_OPENMODELICA_KEYWORDS:
       return tr("Please make sure you are not using any OpenModelica Keywords like (model, package, record, class etc.)");
     case UNABLE_TO_LOAD_FILE:
@@ -551,6 +561,8 @@ QString GUIMessages::getMessage(int type)
       return tr("The file <b>%1</b> is not a valid Modelica file. The file format is not supported. You can only open <b>%2</b>.");
     case ENTER_VALID_NUMBER:
       return tr("Enter a valid number value for <b>%1</b>.");
+    case ENTER_VALUE:
+      return tr("Enter a value for <b>%1</b>.");
     case ITEM_DROPPED_ON_ITSELF:
       return tr("You cannot drop an item on itself.");
     case MAKE_REPLACEABLE_IF_PARTIAL:
@@ -572,15 +584,7 @@ QString GUIMessages::getMessage(int type)
     case WRONG_MODIFIER:
       return tr("The Modifier <b>%1</b> format is invalid. The correct format is <b>phi(start=1)</b>");
     case SET_INFO_XML_FLAG:
-      return tr("The operations were not generated. Check Generate Operations in %1 OR you must set the +d=infoXmlOperations flag via %2 and simulate again.");
-    case GENERATE_OPERATIONS_MSG:
-      return tr("Tools->Options->Debugger->Transformational Debugger");
-    case GENERATE_OPERATIONS_MSG_MAC:
-      return tr("OMEdit->Preferences->Debugger->Transformational Debugger");
-    case SET_INFO_XML_FLAG_MSG:
-      return tr("Tools->Options->Simulation->OMC Flags");
-    case SET_INFO_XML_FLAG_MSG_MAC:
-      return tr("OMEdit->Preferences->Simulation->OMC Flags");
+      return tr("The operations were not generated. Check Generate Operations in <b>%1->Debugger->Transformational Debugger</b> OR you must set the +d=infoXmlOperations flag via <b>%2->Simulation->OMC Flags</b> and simulate again.");
     case DEBUG_CONFIGURATION_EXISTS_MSG:
       return tr("A debug configuration with name <b>%1</b> already exists. Error occurred while saving the debug configuration <b>%2<b>.");
     case DEBUG_CONFIGURATION_SIZE_EXCEED:
@@ -596,15 +600,13 @@ QString GUIMessages::getMessage(int type)
     case BREAKPOINT_INSERT_NOT_MODELICA_CLASS:
       return tr("The class <b>%1</b> is not a modelica class. Breakpoints are only allowed on modelica classes.");
     case TLMMANAGER_NOT_SET:
-      return tr("TLM Manager executable path is not set. Set it via <b>%1</b>");
-    case TLMMANAGER_NOT_SET_MSG:
-      return tr("Tools->Options->TLM");
-    case TLMMANAGER_NOT_SET_MSG_MAC:
-      return tr("OMEdit->Preferences->TLM");
+      return tr("TLM Manager executable path is not set. Set it via <b>%1->TLM</b>");
     case METAMODEL_UNSAVED:
       return tr("Metamodel <b>%1</b> has unsaved changes. Do you want to save?");
     case TLMCOSIMULATION_ALREADY_RUNNING:
       return tr("TLM co-simulation session is already running. Only one session is allowed.");
+    case TERMINAL_COMMAND_NOT_SET:
+      return tr("Terminal command is not set. You can define a new terminal command in <b>%1->General->Terminal Command</b>.");
     default:
       return "";
   }
