@@ -105,12 +105,7 @@ namespace IAEX {
   };
 
 
-
   /*!
-  * \class MyTextEdit2
-  * \author Anders Ferström
-  * \date 2005-11-01
-  *
   * \brief Extends QTextEdit. Mostly so I can catch when a user
   * clicks on the editor
   */
@@ -183,7 +178,6 @@ namespace IAEX {
   */
   void MyTextEdit3::keyPressEvent(QKeyEvent *event )
   {
-    emit showVariableButton(false);
     // EVAL, key: SHIFT + RETURN || SHIFT + ENTER
     if( event->modifiers() == Qt::ShiftModifier &&
       (event->key() == Qt::Key_Return || event->key() == Qt::Key_Enter) )
@@ -483,7 +477,7 @@ namespace IAEX {
     createLatexCell();
     createOutputCell();
 
-    connect(input_, SIGNAL(showVariableButton(bool)), this, SLOT(showVariableButton(bool)));
+    //connect(input_, SIGNAL(showVariableButton(bool)), this, SLOT(showVariableButton(bool)));
 
     //connect(output_, SIGNAL(anchorClicked(const QUrl&)), input_, SLOT(goToPos(const QUrl&)));
 
@@ -526,15 +520,8 @@ namespace IAEX {
   {
 
     input_ = new MyTextEdit3( mainWidget() );
-    variableButton = new QPushButton("D",input_);
-    variableButton->setToolTip("New simulation data available");
-    variableButton->setMaximumWidth(25);
     layout_->addWidget( input_, 1, 1 );
-    layout_->addWidget(variableButton, 1, 2);
-    variableButton->hide();
-    // 2006-03-02 AF, Add a chapter counter
     createChapterCounter();
-
     input_->setReadOnly( true );
     input_->setUndoRedoEnabled( true );
     input_->setFrameShape( QFrame::Box );
@@ -548,23 +535,21 @@ namespace IAEX {
 
    // palette.setColor(input_->backgroundRole(), QColor(Qt::lightGray));
     palette.setColor(input_->backgroundRole(),QColor(247,247,247));
-
     input_->setPalette(palette);
-
-    variableButton->setPalette(palette);
     // is this needed, don't know /AF
     input_->installEventFilter(this);
-
-    connect( input_, SIGNAL( textChanged() ), this, SLOT( contentChanged() ));
+    connect( input_, SIGNAL( textChanged() ), this, SLOT( contentChanged()));
     connect( input_, SIGNAL( clickOnCell() ), this, SLOT( clickEvent() ));
     connect( input_, SIGNAL( wheelMove(QWheelEvent*) ), this, SLOT( wheelEvent(QWheelEvent*) ));
     connect( input_, SIGNAL( eval() ), this, SLOT( eval() ));
     connect( input_, SIGNAL( command() ), this, SLOT( command() ));
     connect( input_, SIGNAL( nextCommand() ), this, SLOT( nextCommand() ));
     connect( input_, SIGNAL( nextField() ), this, SLOT( nextField() ));
-   // connect( input_, SIGNAL( textChanged() ), this, SLOT( addToHighlighter() ));
+    connect( input_, SIGNAL( nextField() ), this, SLOT( nextField() ));
+
+    //connect( input_, SIGNAL( textChanged() ), this, SLOT( addToHighlighter() ));
     connect( input_, SIGNAL( currentCharFormatChanged(const QTextCharFormat &) ),
-      this, SLOT( charFormatChanged(const QTextCharFormat &) ));
+       this, SLOT( charFormatChanged(const QTextCharFormat &) ));
     connect( input_, SIGNAL( forwardAction(int) ), this, SIGNAL( forwardAction(int) ));
 
     connect( input_, SIGNAL(updatePos(int, int)), this, SIGNAL(updatePos(int, int)));
@@ -574,14 +559,6 @@ namespace IAEX {
     connect(input_, SIGNAL(textChanged()), input_, SLOT(setModified()));
   }
 
-  void LatexCell::showVariableButton(bool b)
-  {
-    if(b)
-      variableButton->show();
-    else
-      variableButton->hide();
-  }
-
   /*!
   * \brief Creates the QTextEdit for the output part of the
   * LatexCell
@@ -591,22 +568,18 @@ namespace IAEX {
   {
     output_ = new MyTextEdit3( mainWidget() );
     layout_->addWidget( output_, 2, 1 );
-
     output_->setReadOnly( true );
-
+    output_->setUndoRedoEnabled( true );
     output_->setOpenLinks(false);
-
     output_->setFrameShape( QFrame::Box );
     output_->setAutoFormatting( QTextEdit::AutoNone );
-
     output_->setHorizontalScrollBarPolicy( Qt::ScrollBarAlwaysOff );
     output_->setVerticalScrollBarPolicy( Qt::ScrollBarAlwaysOff );
-
     connect( output_, SIGNAL( textChanged() ), this, SLOT(contentChanged()));
     connect( output_, SIGNAL( clickOnCell() ), this, SLOT( clickEventOutput() ));
     connect( output_, SIGNAL( wheelMove(QWheelEvent*) ), this, SLOT( wheelEvent(QWheelEvent*) ));
-
     connect(output_, SIGNAL(forwardAction(int)), this, SIGNAL(forwardAction(int)));
+    connect(output_, SIGNAL(textChanged()), output_, SLOT(setModified()));
 
     setOutputStyle();
 
@@ -1150,10 +1123,31 @@ void LatexCell::eval()
        *     equations and formula structures
        */
 
+    /*!
+     * transfer the latex source to output cell and display the final output in
+     * inputcell to have better view with hiding latex source and also maintain the
+     * height of the final output to keep the Notebook precise.Any changes made to
+     * latex source after first evaluation is done from outputcell.
+     */
+
+    QString expr;
+    if(!evaluated_)
+     {
+       output_->setText(input_->toPlainText());
+       QString latexexpr=output_->toPlainText();
+       expr=latexexpr;
+      }
+    else
+       {
+        QString latexexpr=output_->toPlainText();
+        expr=latexexpr;
+    }
+    //output_->setReadOnly(false);
     input_->blockSignals(true);
     output_->blockSignals(true);
-    output_->textCursor().insertText("");
+    //output_->textCursor().insertText("");
     setState(Eval_l);
+    input_->setReadOnly(true);
     bool setdvi=false;
     bool setpng=false;
     bool setpage=false;
@@ -1171,10 +1165,14 @@ void LatexCell::eval()
     QString Png = tempfname + ".png";
     QString log = tempfname + ".log";
 
-    QString expr = input_->toPlainText();
+    //QString expr = input_->toPlainText();
     if (!expr.isEmpty())
     {
         expr.replace("\\begin{document}","\\begin{document} \\thispagestyle{empty}");
+        if (!expr.contains("\\begin{document}")) {
+            expr.prepend("\\documentclass{article}\\begin{document}\\thispagestyle{empty}");
+            expr.append("\\end{document}");
+        }
         QFile file(Tex);
         file.open(QIODevice::WriteOnly);
         QTextStream stream(&file);
@@ -1193,10 +1191,7 @@ void LatexCell::eval()
         /* Check for latex is installed */
         if (Latexversion.isEmpty())
         {
-            //qDebug()<< "Latex is not installed in your system";
-            output_->clear();
-            output_->textCursor().insertText("Error: Latex is not installed in your System");
-            setClosed(false);
+            QMessageBox::warning( 0, "Error", "Latex is not installed in your System, This cell cannot be evaluated", "OK" );
         }
         /*Generate the DVI file from tex through latex */
         if (!Latexversion.isEmpty())
@@ -1221,8 +1216,8 @@ void LatexCell::eval()
             QFileInfo checkdvi(Dvi);
             if(!checkdvi.exists())
             {
-                output_->clear();
-                output_->textCursor().insertText(texoutput);
+                input_->clear();
+                input_->textCursor().insertText(texoutput);
                 setClosed(false);
             }
             else
@@ -1239,35 +1234,35 @@ void LatexCell::eval()
             // check for number of pages tex script generates
             if(setpage==true)
             {
-                process->start("dvipng",QStringList() << Dvi << "-o" << Png);
+                process->start("dvipng",QStringList() << "-T" << "tight" << Dvi << "-o" << Png);
                 process->waitForFinished();
                 QFileInfo checkpng(Png);
                 if(!checkpng.exists())
                 {
-                    output_->textCursor().insertText("Error:Problem in finding dvipng executable");
+                    input_->clear();
+                    input_->textCursor().insertText("Error:Problem in finding dvipng executable");
                     setClosed(false);
+
                 }
                 else
                 {
-                    output_->clear();
-                    output_->textCursor().insertImage(Png);
-                    setClosed(false);
+                    input_->clear();
+                    input_->textCursor().insertImage(Png);
+                    setClosed(true);
                 }
             }
             else
             {
-                output_->clear();
-                output_->textCursor().insertText("Message:Maximum of 1 page document generation is supported per Latexcell, The script generates more than 1 page, Add a new Latex cell and create the document");
-                setClosed(false);
 
+                QMessageBox::warning( 0, "Warning", "Maximum of 1 page document generation is supported per Latexcell, The script generates more than 1 page", "OK" );
             }
         }
     }
     else
     {
         //qDebug()<< "Empty cells can't be evaluated";
-        output_->clear();
-        output_->textCursor().insertText("Message: Empty Cells cannot be Evaluated");
+        input_->clear();
+        input_->textCursor().insertText("Message: Empty Latex Cells cannot be Evaluated");
         setClosed(false);
     }
     input_->blockSignals(false);
@@ -1319,6 +1314,7 @@ void LatexCell::setState(int state_)
 
     if( commandcompletion->nextCommand( cursor ))
       input_->setTextCursor( cursor );
+
   }
 
   /*!
@@ -1331,6 +1327,7 @@ void LatexCell::setState(int state_)
 
     if( commandcompletion->nextField( cursor ))
       input_->setTextCursor( cursor );
+
   }
 
 
@@ -1339,7 +1336,6 @@ void LatexCell::setState(int state_)
   * cell is empty. This is done because otherwise the style is lost if
   * all text is removed inside a cell.
   */
-
   void LatexCell::charFormatChanged(const QTextCharFormat &)
   {
     input_->blockSignals( true );
